searchData={"items":[{"type":"module","title":"BinaryGcd","doc":"A module implementing the binary GCD algorithm (also known as Stein's algorithm).\n\nThe binary GCD algorithm is an efficient method for computing the greatest common divisor\nof two non-negative integers. It uses only subtraction and bit operations, making it\nparticularly fast for large numbers.","ref":"BinaryGcd.html"},{"type":"module","title":"Algorithm Overview - BinaryGcd","doc":"The binary GCD algorithm works by:\n1. If both numbers are even, divide both by 2 and multiply the result by 2\n2. If one number is even, divide it by 2\n3. If both numbers are odd, subtract the smaller from the larger\n4. Repeat until one number becomes zero","ref":"BinaryGcd.html#module-algorithm-overview"},{"type":"module","title":"Performance - BinaryGcd","doc":"This algorithm is generally faster than the Euclidean algorithm for large numbers\nbecause it avoids expensive division operations, using only bit shifts and subtraction.","ref":"BinaryGcd.html#module-performance"},{"type":"module","title":"Examples - BinaryGcd","doc":"iex> BinaryGcd.of(48, 18)\n    6\n\n    iex> BinaryGcd.of(0, 5)\n    5\n\n    iex> BinaryGcd.of(12, 0)\n    12\n\n    iex> BinaryGcd.of(54, 24)\n    6","ref":"BinaryGcd.html#module-examples"},{"type":"function","title":"BinaryGcd.of/2","doc":"Computes the greatest common divisor of two non-negative integers using the binary GCD algorithm.","ref":"BinaryGcd.html#of/2"},{"type":"function","title":"Parameters - BinaryGcd.of/2","doc":"* `m` - First non-negative integer\n  * `n` - Second non-negative integer","ref":"BinaryGcd.html#of/2-parameters"},{"type":"function","title":"Returns - BinaryGcd.of/2","doc":"* The greatest common divisor of `m` and `n`","ref":"BinaryGcd.html#of/2-returns"},{"type":"function","title":"Examples - BinaryGcd.of/2","doc":"iex> BinaryGcd.of(48, 18)\n    6\n\n    iex> BinaryGcd.of(0, 5)\n    5\n\n    iex> BinaryGcd.of(12, 0)\n    12\n\n    iex> BinaryGcd.of(54, 24)\n    6\n\n    iex> BinaryGcd.of(17, 13)\n    1","ref":"BinaryGcd.html#of/2-examples"},{"type":"function","title":"Algorithm Steps - BinaryGcd.of/2","doc":"1. **Base cases**: If either number is 0, return the other number\n2. **Both even**: If both numbers are even, divide both by 2, compute GCD, then multiply by 2\n3. **One even**: If only one number is even, divide it by 2 and continue\n4. **Both odd**: If both numbers are odd, subtract the smaller from the larger and continue\n5. **Recursion**: Continue until one number becomes zero","ref":"BinaryGcd.html#of/2-algorithm-steps"},{"type":"extras","title":"BinaryGcd","doc":"# BinaryGcd\n\nAn efficient Elixir implementation of the binary GCD algorithm (Stein's algorithm) for computing the greatest common divisor (GCD) of two non-negative integers using only bitwise operations and subtraction.","ref":"readme.html"},{"type":"extras","title":"Features - BinaryGcd","doc":"- Fast GCD computation using Stein's algorithm\n- Pure Elixir, no dependencies for core logic\n- Well-documented and tested\n- Suitable for large integers","ref":"readme.html#features"},{"type":"extras","title":"Installation - BinaryGcd","doc":"","ref":"readme.html#installation"},{"type":"extras","title":"From Hex (Recommended) - BinaryGcd","doc":"Add `binary_gcd` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:binary_gcd, \"~> 1.0\"}\n  ]\nend\n```\n\nThen run:\n\n```bash\nmix deps.get\n```","ref":"readme.html#from-hex-recommended"},{"type":"extras","title":"Usage - BinaryGcd","doc":"You can use the module directly in your code or in IEx:\n\n```elixir\niex> BinaryGcd.of(48, 18)\n6\n\niex> BinaryGcd.of(0, 5)\n5\n\niex> BinaryGcd.of(54, 24)\n6\n\niex> BinaryGcd.of(17, 13)\n1\n```","ref":"readme.html#usage"},{"type":"extras","title":"Algorithm - BinaryGcd","doc":"This library implements the binary GCD algorithm, also known as Stein's algorithm. It is generally faster than the classical Euclidean algorithm for large numbers because it avoids division and uses only subtraction and bitwise operations.\n\n**Algorithm steps:**\n1. If either number is zero, return the other number.\n2. If both numbers are even, divide both by 2 and multiply the result by 2.\n3. If one number is even, divide it by 2.\n4. If both numbers are odd, subtract the smaller from the larger.\n5. Repeat until one number becomes zero.","ref":"readme.html#algorithm"},{"type":"extras","title":"Tested Platforms - BinaryGcd","doc":"* Ubuntu 22.04 / Elixir 1.18 / Erlang/OTP 28","ref":"readme.html#tested-platforms"},{"type":"extras","title":"License - BinaryGcd","doc":"Copyright (c) 2025 University of Kitakyushu\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at [http://www.apache.org/licenses/LICENSE-2.0](http://www.apache.org/licenses/LICENSE-2.0)\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.","ref":"readme.html#license"},{"type":"extras","title":"LICENSE","doc":"Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\n   TERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n   1. Definitions.\n\n      \"License\" shall mean the terms and conditions for use, reproduction,\n      and distribution as defined by Sections 1 through 9 of this document.\n\n      \"Licensor\" shall mean the copyright owner or entity authorized by\n      the copyright owner that is granting the License.\n\n      \"Legal Entity\" shall mean the union of the acting entity and all\n      other entities that control, are controlled by, or are under common\n      control with that entity. For the purposes of this definition,\n      \"control\" means (i) the power, direct or indirect, to cause the\n      direction or management of such entity, whether by contract or\n      otherwise, or (ii) ownership of fifty percent (50%) or more of the\n      outstanding shares, or (iii) beneficial ownership of such entity.\n\n      \"You\" (or \"Your\") shall mean an individual or Legal Entity\n      exercising permissions granted by this License.\n\n      \"Source\" form shall mean the preferred form for making modifications,\n      including but not limited to software source code, documentation\n      source, and configuration files.\n\n      \"Object\" form shall mean any form resulting from mechanical\n      transformation or translation of a Source form, including but\n      not limited to compiled object code, generated documentation,\n      and conversions to other media types.\n\n      \"Work\" shall mean the work of authorship, whether in Source or\n      Object form, made available under the License, as indicated by a\n      copyright notice that is included in or attached to the work\n      (an example is provided in the Appendix below).\n\n      \"Derivative Works\" shall mean any work, whether in Source or Object\n      form, that is based on (or derived from) the Work and for which the\n      editorial revisions, annotations, elaborations, or other modifications\n      represent, as a whole, an original work of authorship. For the purposes\n      of this License, Derivative Works shall not include works that remain\n      separable from, or merely link (or bind by name) to the interfaces of,\n      the Work and Derivative Works thereof.\n\n      \"Contribution\" shall mean any work of authorship, including\n      the original version of the Work and any modifications or additions\n      to that Work or Derivative Works thereof, that is intentionally\n      submitted to Licensor for inclusion in the Work by the copyright owner\n      or by an individual or Legal Entity authorized to submit on behalf of\n      the copyright owner. For the purposes of this definition, \"submitted\"\n      means any form of electronic, verbal, or written communication sent\n      to the Licensor or its representatives, including but not limited to\n      communication on electronic mailing lists, source code control systems,\n      and issue tracking systems that are managed by, or on behalf of, the\n      Licensor for the purpose of discussing and improving the Work, but\n      excluding communication that is conspicuously marked or otherwise\n      designated in writing by the copyright owner as \"Not a Contribution.\"\n\n      \"Contributor\" shall mean Licensor and any individual or Legal Entity\n      on behalf of whom a Contribution has been received by Licensor and\n      subsequently incorporated within the Work.\n\n   2. Grant of Copyright License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      copyright license to reproduce, prepare Derivative Works of,\n      publicly display, publicly perform, sublicense, and distribute the\n      Work and such Derivative Works in Source or Object form.\n\n   3. Grant of Patent License. Subject to the terms and conditions of\n      this License, each Contributor hereby grants to You a perpetual,\n      worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n      (except as stated in this section) patent license to make, have made,\n      use, offer to sell, sell, import, and otherwise transfer the Work,\n      where such license applies only to those patent claims licensable\n      by such Contributor that are necessarily infringed by their\n      Contribution(s) alone or by combination of their Contribution(s)\n      with the Work to which such Contribution(s) was submitted. If You\n      institute patent litigation against any entity (including a\n      cross-claim or counterclaim in a lawsuit) alleging that the Work\n      or a Contribution incorporated within the Work constitutes direct\n      or contributory patent infringement, then any patent licenses\n      granted to You under this License for that Work shall terminate\n      as of the date such litigation is filed.\n\n   4. Redistribution. You may reproduce and distribute copies of the\n      Work or Derivative Works thereof in any medium, with or without\n      modifications, and in Source or Object form, provided that You\n      meet the following conditions:\n\n      (a) You must give any other recipients of the Work or\n          Derivative Works a copy of this License; and\n\n      (b) You must cause any modified files to carry prominent notices\n          stating that You changed the files; and\n\n      (c) You must retain, in the Source form of any Derivative Works\n          that You distribute, all copyright, patent, trademark, and\n          attribution notices from the Source form of the Work,\n          excluding those notices that do not pertain to any part of\n          the Derivative Works; and\n\n      (d) If the Work includes a \"NOTICE\" text file as part of its\n          distribution, then any Derivative Works that You distribute must\n          include a readable copy of the attribution notices contained\n          within such NOTICE file, excluding those notices that do not\n          pertain to any part of the Derivative Works, in at least one\n          of the following places: within a NOTICE text file distributed\n          as part of the Derivative Works; within the Source form or\n          documentation, if provided along with the Derivative Works; or,\n          within a display generated by the Derivative Works, if and\n          wherever such third-party notices normally appear. The contents\n          of the NOTICE file are for informational purposes only and\n          do not modify the License. You may add Your own attribution\n          notices within Derivative Works that You distribute, alongside\n          or as an addendum to the NOTICE text from the Work, provided\n          that such additional attribution notices cannot be construed\n          as modifying the License.\n\n      You may add Your own copyright statement to Your modifications and\n      may provide additional or different license terms and conditions\n      for use, reproduction, or distribution of Your modifications, or\n      for any such Derivative Works as a whole, provided Your use,\n      reproduction, and distribution of the Work otherwise complies with\n      the conditions stated in this License.\n\n   5. Submission of Contributions. Unless You explicitly state otherwise,\n      any Contribution intentionally submitted for inclusion in the Work\n      by You to the Licensor shall be under the terms and conditions of\n      this License, without any additional terms or conditions.\n      Notwithstanding the above, nothing herein shall supersede or modify\n      the terms of any separate license agreement you may have executed\n      with Licensor regarding such Contributions.\n\n   6. Trademarks. This License does not grant permission to use the trade\n      names, trademarks, service marks, or product names of the Licensor,\n      except as required for reasonable and customary use in describing the\n      origin of the Work and reproducing the content of the NOTICE file.\n\n   7. Disclaimer of Warranty. Unless required by applicable law or\n      agreed to in writing, Licensor provides the Work (and each\n      Contributor provides its Contributions) on an \"AS IS\" BASIS,\n      WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n      implied, including, without limitation, any warranties or conditions\n      of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n      PARTICULAR PURPOSE. You are solely responsible for determining the\n      appropriateness of using or redistributing the Work and assume any\n      risks associated with Your exercise of permissions under this License.\n\n   8. Limitation of Liability. In no event and under no legal theory,\n      whether in tort (including negligence), contract, or otherwise,\n      unless required by applicable law (such as deliberate and grossly\n      negligent acts) or agreed to in writing, shall any Contributor be\n      liable to You for damages, including any direct, indirect, special,\n      incidental, or consequential damages of any character arising as a\n      result of this License or out of the use or inability to use the\n      Work (including but not limited to damages for loss of goodwill,\n      work stoppage, computer failure or malfunction, or any and all\n      other commercial damages or losses), even if such Contributor\n      has been advised of the possibility of such damages.\n\n   9. Accepting Warranty or Additional Liability. While redistributing\n      the Work or Derivative Works thereof, You may choose to offer,\n      and charge a fee for, acceptance of support, warranty, indemnity,\n      or other liability obligations and/or rights consistent with this\n      License. However, in accepting such obligations, You may act only\n      on Your own behalf and on Your sole responsibility, not on behalf\n      of any other Contributor, and only if You agree to indemnify,\n      defend, and hold each Contributor harmless for any liability\n      incurred by, or claims asserted against, such Contributor by reason\n      of your accepting any such warranty or additional liability.\n\n   END OF TERMS AND CONDITIONS\n\n   APPENDIX: How to apply the Apache License to your work.\n\n      To apply the Apache License to your work, attach the following\n      boilerplate notice, with the fields enclosed by brackets \"[]\"\n      replaced with your own identifying information. (Don't include\n      the brackets!)  The text should be enclosed in the appropriate\n      comment syntax for the file format. We also recommend that a\n      file or class name and description of purpose be included on the\n      same \"printed page\" as the copyright notice for easier\n      identification within third-party archives.\n\n   Copyright [yyyy] [name of copyright owner]\n\n   Licensed under the Apache License, Version 2.0 (the \"License\");\n   you may not use this file except in compliance with the License.\n   You may obtain a copy of the License at\n\n       http://www.apache.org/licenses/LICENSE-2.0\n\n   Unless required by applicable law or agreed to in writing, software\n   distributed under the License is distributed on an \"AS IS\" BASIS,\n   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n   See the License for the specific language governing permissions and\n   limitations under the License.","ref":"license.html"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [1.0.0] - 2025-07-18","ref":"changelog.html"},{"type":"extras","title":"Added - Changelog","doc":"- Initial implementation of BinaryGcd module with `of/2` function\n- Binary GCD algorithm (Stein's algorithm) implementation\n- Comprehensive documentation with usage examples\n- Full test suite with edge cases\n- Code quality tools integration (nstandard, credo, dialyzer)\n- Documentation generation with ExDoc\n- Spell checking with Spellweaver\n- GitHub Actions CI workflow for automated testing and code quality checks\n- Dependabot configuration for automated dependency updates\n- Development tooling setup","ref":"changelog.html#added"},{"type":"extras","title":"Features - Changelog","doc":"- Fast GCD computation using Stein's algorithm\n- Pure Elixir implementation with no external dependencies for core logic\n- Support for large integers with efficient bitwise operations\n- Comprehensive error handling and edge case coverage\n- Well-documented API with detailed examples","ref":"changelog.html#features"},{"type":"extras","title":"Technical Details - Changelog","doc":"- Uses only bitwise operations and subtraction (no division)\n- Optimized for large numbers where traditional Euclidean algorithm is slower\n- Handles edge cases: zero values, single zero, and coprime numbers\n- Type specifications for better code quality and IDE support\n\n\n---","ref":"changelog.html#technical-details"},{"type":"extras","title":"Version History - Changelog","doc":"- **1.0.0**: Initial stable release with complete BinaryGcd implementation","ref":"changelog.html#version-history"},{"type":"extras","title":"Contributing - Changelog","doc":"When contributing to this project, please update this changelog by adding a new entry under the [Unreleased] section. The entry should follow the format:\n\n```","ref":"changelog.html#contributing"},{"type":"extras","title":"Added - Changelog","doc":"- New feature description","ref":"changelog.html#added-1"},{"type":"extras","title":"Changed - Changelog","doc":"- Changed feature description","ref":"changelog.html#changed"},{"type":"extras","title":"Deprecated - Changelog","doc":"- Deprecated feature description","ref":"changelog.html#deprecated"},{"type":"extras","title":"Removed - Changelog","doc":"- Removed feature description","ref":"changelog.html#removed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Bug fix description","ref":"changelog.html#fixed"},{"type":"extras","title":"Security - Changelog","doc":"- Security fix description\n```","ref":"changelog.html#security"},{"type":"extras","title":"Release Process - Changelog","doc":"1. Update version in `mix.exs`\n2. Update this changelog with release date\n3. Create a git tag for the release\n4. Push changes and tag to repository","ref":"changelog.html#release-process"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}